#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parser-combinators
version:              1.3.0
visibility:           public
id:                   parser-combinators-1.3.0-I56cvBuZMEG2VbjtPZAqZY
key:                  parser-combinators-1.3.0-I56cvBuZMEG2VbjtPZAqZY
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Mark Karpov <markkarpov92@gmail.com>
    Alex Washburn <github@recursion.ninja>

homepage:             https://github.com/mrkkrp/parser-combinators
synopsis:
    Lightweight package providing commonly useful parser combinators

description:
    Lightweight package providing commonly useful parser combinators.

category:             Parsing
abi:                  e3a5397c86ad8366df258821768c8554
exposed:              True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
    Control.Monad.Permutations

import-dirs:          /usr/lib/ghc-8.10.5/site-local/parser-combinators-1.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/parser-combinators-1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/parser-combinators-1.3.0
hs-libraries:         HSparser-combinators-1.3.0-I56cvBuZMEG2VbjtPZAqZY
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock

haddock-html:         /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

